@@ -72,7 +72,7 @@ namespace libdar
 	cat_directory(const cat_directory &ref); // only the inode part is build, no children is duplicated (empty dir)
 	cat_directory(cat_directory && ref) noexcept;
 	cat_directory & operator = (const cat_directory & ref); // set the inode part *only* no subdirectories/subfiles are copies or removed.
-	cat_directory & operator = (cat_directory && ref) noexcept;
+	cat_directory & operator = (cat_directory && ref);
         ~cat_directory() noexcept(false); // detruit aussi tous les fils et se supprime de son 'parent'
 
 	    /// attention this compares only the directories themselves, not the list of their children
