@@ -1,6 +1,6 @@
 /*********************************************************************/
 // dar - disk archive - a backup/restoration program
-// Copyright (C) 2002-2023 Denis Corbin
+// Copyright (C) 2002-2024 Denis Corbin
 //
 // This program is free software; you can redistribute it and/or
 // modify it under the terms of the GNU General Public License
@@ -95,6 +95,9 @@
     // for remote reposity you will need to create such object and pass it where needed
 #include "entrepot_libcurl.hpp"
 
+    // for local filesystem, you should not need to create such object to call libdar as it is the default repo used
+#include "entrepot_local.hpp"
+
     // the options class to give non default parameter to the archive class
 #include "archive_options_listing_shell.hpp"
 
